# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_mms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_clientserver_mms.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$steammessages_clientserver_mms.proto\x1a\x18steammessages_base.proto\"\x98\x01\n\'CMsgClientMMSSetRatelimitPolicyOnClient\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x1a\n\x12\x65nable_rate_limits\x18\x02 \x01(\x08\x12\x1b\n\x13seconds_per_message\x18\x03 \x01(\x05\x12$\n\x1cmilliseconds_per_data_update\x18\x04 \x01(\x05\"\xe8\x01\n\x18\x43MsgClientMMSCreateLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x13\n\x0bmax_members\x18\x02 \x01(\x05\x12\x12\n\nlobby_type\x18\x03 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x04 \x01(\x05\x12\x0f\n\x07\x63\x65ll_id\x18\x05 \x01(\r\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x06 \x01(\r\x12\x10\n\x08metadata\x18\x07 \x01(\x0c\x12\x1a\n\x12persona_name_owner\x18\x08 \x01(\t\x12!\n\tpublic_ip\x18\t \x01(\x0b\x32\x0e.CMsgIPAddress\"^\n CMsgClientMMSCreateLobbyResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"V\n\x16\x43MsgClientMMSJoinLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x03 \x01(\t\"\xcf\x02\n\x1e\x43MsgClientMMSJoinLobbyResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12 \n\x18\x63hat_room_enter_response\x18\x03 \x01(\x05\x12\x13\n\x0bmax_members\x18\x04 \x01(\x05\x12\x12\n\nlobby_type\x18\x05 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x06 \x01(\x05\x12\x16\n\x0esteam_id_owner\x18\x07 \x01(\x06\x12\x10\n\x08metadata\x18\x08 \x01(\x0c\x12\x37\n\x07members\x18\t \x03(\x0b\x32&.CMsgClientMMSJoinLobbyResponse.Member\x1a\x42\n\x06Member\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\"A\n\x17\x43MsgClientMMSLeaveLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\"]\n\x1f\x43MsgClientMMSLeaveLobbyResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"\xa0\x02\n\x19\x43MsgClientMMSGetLobbyList\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x1d\n\x15num_lobbies_requested\x18\x03 \x01(\x05\x12\x0f\n\x07\x63\x65ll_id\x18\x04 \x01(\r\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x05 \x01(\r\x12\x32\n\x07\x66ilters\x18\x06 \x03(\x0b\x32!.CMsgClientMMSGetLobbyList.Filter\x12!\n\tpublic_ip\x18\x07 \x01(\x0b\x32\x0e.CMsgIPAddress\x1aN\n\x06\x46ilter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x13\n\x0b\x63omparision\x18\x03 \x01(\x05\x12\x13\n\x0b\x66ilter_type\x18\x04 \x01(\x05\"\xa5\x02\n!CMsgClientMMSGetLobbyListResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\x12\x39\n\x07lobbies\x18\x04 \x03(\x0b\x32(.CMsgClientMMSGetLobbyListResponse.Lobby\x1a\xa0\x01\n\x05Lobby\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x13\n\x0bmax_members\x18\x02 \x01(\x05\x12\x12\n\nlobby_type\x18\x03 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x04 \x01(\x05\x12\x10\n\x08metadata\x18\x05 \x01(\x0c\x12\x13\n\x0bnum_members\x18\x06 \x01(\x05\x12\x10\n\x08\x64istance\x18\x07 \x01(\x02\x12\x0e\n\x06weight\x18\x08 \x01(\x03\"\xac\x01\n\x19\x43MsgClientMMSSetLobbyData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_member\x18\x03 \x01(\x06\x12\x13\n\x0bmax_members\x18\x04 \x01(\x05\x12\x12\n\nlobby_type\x18\x05 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x06 \x01(\x05\x12\x10\n\x08metadata\x18\x07 \x01(\x0c\"_\n!CMsgClientMMSSetLobbyDataResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"C\n\x19\x43MsgClientMMSGetLobbyData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\"\xed\x02\n\x16\x43MsgClientMMSLobbyData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x13\n\x0bnum_members\x18\x03 \x01(\x05\x12\x13\n\x0bmax_members\x18\x04 \x01(\x05\x12\x12\n\nlobby_type\x18\x05 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x06 \x01(\x05\x12\x16\n\x0esteam_id_owner\x18\x07 \x01(\x06\x12\x10\n\x08metadata\x18\x08 \x01(\x0c\x12/\n\x07members\x18\t \x03(\x0b\x32\x1e.CMsgClientMMSLobbyData.Member\x12\x14\n\x0clobby_cellid\x18\n \x01(\r\x12#\n\x1bowner_should_accept_changes\x18\x0b \x01(\x08\x1a\x42\n\x06Member\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\"w\n\x1d\x43MsgClientMMSSendLobbyChatMsg\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_target\x18\x03 \x01(\x06\x12\x15\n\rlobby_message\x18\x04 \x01(\x0c\"s\n\x19\x43MsgClientMMSLobbyChatMsg\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_sender\x18\x03 \x01(\x06\x12\x15\n\rlobby_message\x18\x04 \x01(\x0c\"`\n\x1a\x43MsgClientMMSSetLobbyOwner\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x1a\n\x12steam_id_new_owner\x18\x03 \x01(\x06\"`\n\"CMsgClientMMSSetLobbyOwnerResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"^\n\x1b\x43MsgClientMMSSetLobbyLinked\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_lobby2\x18\x03 \x01(\x06\"\xcc\x01\n\x1f\x43MsgClientMMSSetLobbyGameServer\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12!\n\x19\x64\x65precated_game_server_ip\x18\x03 \x01(\r\x12\x18\n\x10game_server_port\x18\x04 \x01(\r\x12\x1c\n\x14game_server_steam_id\x18\x05 \x01(\x06\x12&\n\x0egame_server_ip\x18\x06 \x01(\x0b\x32\x0e.CMsgIPAddress\"\xcc\x01\n\x1f\x43MsgClientMMSLobbyGameServerSet\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12!\n\x19\x64\x65precated_game_server_ip\x18\x03 \x01(\r\x12\x18\n\x10game_server_port\x18\x04 \x01(\r\x12\x1c\n\x14game_server_steam_id\x18\x05 \x01(\x06\x12&\n\x0egame_server_ip\x18\x06 \x01(\x0b\x32\x0e.CMsgIPAddress\"s\n\x1c\x43MsgClientMMSUserJoinedLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x15\n\rsteam_id_user\x18\x03 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x04 \x01(\t\"q\n\x1a\x43MsgClientMMSUserLeftLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x15\n\rsteam_id_user\x18\x03 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x04 \x01(\t\"c\n\x1a\x43MsgClientMMSInviteToLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x1d\n\x15steam_id_user_invited\x18\x03 \x01(\x06\"x\n\x1b\x43MsgClientMMSGetLobbyStatus\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x18\n\x10\x63laim_membership\x18\x03 \x01(\x08\x12\x17\n\x0f\x63laim_ownership\x18\x04 \x01(\x08\"\x8f\x01\n#CMsgClientMMSGetLobbyStatusResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12@\n\x0clobby_status\x18\x03 \x01(\x0e\x32\x10.EMMSLobbyStatus:\x18k_EMMSLobbyStatusInvalid*\x90\x01\n\x0f\x45MMSLobbyStatus\x12\x1c\n\x18k_EMMSLobbyStatusInvalid\x10\x00\x12\x1b\n\x17k_EMMSLobbyStatusExists\x10\x01\x12!\n\x1dk_EMMSLobbyStatusDoesNotExist\x10\x02\x12\x1f\n\x1bk_EMMSLobbyStatusNotAMember\x10\x03\x42\x05H\x01\x90\x01\x00'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,])

_EMMSLOBBYSTATUS = _descriptor.EnumDescriptor(
  name='EMMSLobbyStatus',
  full_name='EMMSLobbyStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMMSLobbyStatusInvalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMMSLobbyStatusExists', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMMSLobbyStatusDoesNotExist', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMMSLobbyStatusNotAMember', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3982,
  serialized_end=4126,
)
_sym_db.RegisterEnumDescriptor(_EMMSLOBBYSTATUS)

EMMSLobbyStatus = enum_type_wrapper.EnumTypeWrapper(_EMMSLOBBYSTATUS)
k_EMMSLobbyStatusInvalid = 0
k_EMMSLobbyStatusExists = 1
k_EMMSLobbyStatusDoesNotExist = 2
k_EMMSLobbyStatusNotAMember = 3



_CMSGCLIENTMMSSETRATELIMITPOLICYONCLIENT = _descriptor.Descriptor(
  name='CMsgClientMMSSetRatelimitPolicyOnClient',
  full_name='CMsgClientMMSSetRatelimitPolicyOnClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetRatelimitPolicyOnClient.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_rate_limits', full_name='CMsgClientMMSSetRatelimitPolicyOnClient.enable_rate_limits', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_per_message', full_name='CMsgClientMMSSetRatelimitPolicyOnClient.seconds_per_message', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='milliseconds_per_data_update', full_name='CMsgClientMMSSetRatelimitPolicyOnClient.milliseconds_per_data_update', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=219,
)


_CMSGCLIENTMMSCREATELOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSCreateLobby',
  full_name='CMsgClientMMSCreateLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSCreateLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_members', full_name='CMsgClientMMSCreateLobby.max_members', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgClientMMSCreateLobby.lobby_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_flags', full_name='CMsgClientMMSCreateLobby.lobby_flags', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CMsgClientMMSCreateLobby.cell_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_public_ip', full_name='CMsgClientMMSCreateLobby.deprecated_public_ip', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSCreateLobby.metadata', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_name_owner', full_name='CMsgClientMMSCreateLobby.persona_name_owner', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_ip', full_name='CMsgClientMMSCreateLobby.public_ip', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=454,
)


_CMSGCLIENTMMSCREATELOBBYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSCreateLobbyResponse',
  full_name='CMsgClientMMSCreateLobbyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSCreateLobbyResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSCreateLobbyResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientMMSCreateLobbyResponse.eresult', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=550,
)


_CMSGCLIENTMMSJOINLOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSJoinLobby',
  full_name='CMsgClientMMSJoinLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSJoinLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSJoinLobby.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgClientMMSJoinLobby.persona_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=638,
)


_CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='CMsgClientMMSJoinLobbyResponse.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgClientMMSJoinLobbyResponse.Member.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgClientMMSJoinLobbyResponse.Member.persona_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSJoinLobbyResponse.Member.metadata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=976,
)

_CMSGCLIENTMMSJOINLOBBYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSJoinLobbyResponse',
  full_name='CMsgClientMMSJoinLobbyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSJoinLobbyResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSJoinLobbyResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_room_enter_response', full_name='CMsgClientMMSJoinLobbyResponse.chat_room_enter_response', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_members', full_name='CMsgClientMMSJoinLobbyResponse.max_members', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgClientMMSJoinLobbyResponse.lobby_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_flags', full_name='CMsgClientMMSJoinLobbyResponse.lobby_flags', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_owner', full_name='CMsgClientMMSJoinLobbyResponse.steam_id_owner', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSJoinLobbyResponse.metadata', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgClientMMSJoinLobbyResponse.members', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=976,
)


_CMSGCLIENTMMSLEAVELOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSLeaveLobby',
  full_name='CMsgClientMMSLeaveLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSLeaveLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSLeaveLobby.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=978,
  serialized_end=1043,
)


_CMSGCLIENTMMSLEAVELOBBYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSLeaveLobbyResponse',
  full_name='CMsgClientMMSLeaveLobbyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSLeaveLobbyResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSLeaveLobbyResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientMMSLeaveLobbyResponse.eresult', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1045,
  serialized_end=1138,
)


_CMSGCLIENTMMSGETLOBBYLIST_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='CMsgClientMMSGetLobbyList.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='CMsgClientMMSGetLobbyList.Filter.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgClientMMSGetLobbyList.Filter.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comparision', full_name='CMsgClientMMSGetLobbyList.Filter.comparision', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_type', full_name='CMsgClientMMSGetLobbyList.Filter.filter_type', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1351,
  serialized_end=1429,
)

_CMSGCLIENTMMSGETLOBBYLIST = _descriptor.Descriptor(
  name='CMsgClientMMSGetLobbyList',
  full_name='CMsgClientMMSGetLobbyList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSGetLobbyList.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_lobbies_requested', full_name='CMsgClientMMSGetLobbyList.num_lobbies_requested', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CMsgClientMMSGetLobbyList.cell_id', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_public_ip', full_name='CMsgClientMMSGetLobbyList.deprecated_public_ip', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='CMsgClientMMSGetLobbyList.filters', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_ip', full_name='CMsgClientMMSGetLobbyList.public_ip', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTMMSGETLOBBYLIST_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1141,
  serialized_end=1429,
)


_CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY = _descriptor.Descriptor(
  name='Lobby',
  full_name='CMsgClientMMSGetLobbyListResponse.Lobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_members', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.max_members', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.lobby_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_flags', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.lobby_flags', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.metadata', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_members', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.num_members', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.distance', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.weight', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1565,
  serialized_end=1725,
)

_CMSGCLIENTMMSGETLOBBYLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSGetLobbyListResponse',
  full_name='CMsgClientMMSGetLobbyListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSGetLobbyListResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientMMSGetLobbyListResponse.eresult', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobbies', full_name='CMsgClientMMSGetLobbyListResponse.lobbies', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1432,
  serialized_end=1725,
)


_CMSGCLIENTMMSSETLOBBYDATA = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyData',
  full_name='CMsgClientMMSSetLobbyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyData.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyData.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_member', full_name='CMsgClientMMSSetLobbyData.steam_id_member', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_members', full_name='CMsgClientMMSSetLobbyData.max_members', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgClientMMSSetLobbyData.lobby_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_flags', full_name='CMsgClientMMSSetLobbyData.lobby_flags', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSSetLobbyData.metadata', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1728,
  serialized_end=1900,
)


_CMSGCLIENTMMSSETLOBBYDATARESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyDataResponse',
  full_name='CMsgClientMMSSetLobbyDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyDataResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyDataResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientMMSSetLobbyDataResponse.eresult', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1902,
  serialized_end=1997,
)


_CMSGCLIENTMMSGETLOBBYDATA = _descriptor.Descriptor(
  name='CMsgClientMMSGetLobbyData',
  full_name='CMsgClientMMSGetLobbyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSGetLobbyData.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSGetLobbyData.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1999,
  serialized_end=2066,
)


_CMSGCLIENTMMSLOBBYDATA_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='CMsgClientMMSLobbyData.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgClientMMSLobbyData.Member.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgClientMMSLobbyData.Member.persona_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSLobbyData.Member.metadata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=976,
)

_CMSGCLIENTMMSLOBBYDATA = _descriptor.Descriptor(
  name='CMsgClientMMSLobbyData',
  full_name='CMsgClientMMSLobbyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSLobbyData.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSLobbyData.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_members', full_name='CMsgClientMMSLobbyData.num_members', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_members', full_name='CMsgClientMMSLobbyData.max_members', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgClientMMSLobbyData.lobby_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_flags', full_name='CMsgClientMMSLobbyData.lobby_flags', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_owner', full_name='CMsgClientMMSLobbyData.steam_id_owner', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSLobbyData.metadata', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgClientMMSLobbyData.members', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_cellid', full_name='CMsgClientMMSLobbyData.lobby_cellid', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_should_accept_changes', full_name='CMsgClientMMSLobbyData.owner_should_accept_changes', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTMMSLOBBYDATA_MEMBER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2069,
  serialized_end=2434,
)


_CMSGCLIENTMMSSENDLOBBYCHATMSG = _descriptor.Descriptor(
  name='CMsgClientMMSSendLobbyChatMsg',
  full_name='CMsgClientMMSSendLobbyChatMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSendLobbyChatMsg.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSendLobbyChatMsg.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_target', full_name='CMsgClientMMSSendLobbyChatMsg.steam_id_target', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_message', full_name='CMsgClientMMSSendLobbyChatMsg.lobby_message', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2436,
  serialized_end=2555,
)


_CMSGCLIENTMMSLOBBYCHATMSG = _descriptor.Descriptor(
  name='CMsgClientMMSLobbyChatMsg',
  full_name='CMsgClientMMSLobbyChatMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSLobbyChatMsg.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSLobbyChatMsg.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_sender', full_name='CMsgClientMMSLobbyChatMsg.steam_id_sender', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_message', full_name='CMsgClientMMSLobbyChatMsg.lobby_message', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2557,
  serialized_end=2672,
)


_CMSGCLIENTMMSSETLOBBYOWNER = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyOwner',
  full_name='CMsgClientMMSSetLobbyOwner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyOwner.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyOwner.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_new_owner', full_name='CMsgClientMMSSetLobbyOwner.steam_id_new_owner', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2674,
  serialized_end=2770,
)


_CMSGCLIENTMMSSETLOBBYOWNERRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyOwnerResponse',
  full_name='CMsgClientMMSSetLobbyOwnerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyOwnerResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyOwnerResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientMMSSetLobbyOwnerResponse.eresult', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2772,
  serialized_end=2868,
)


_CMSGCLIENTMMSSETLOBBYLINKED = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyLinked',
  full_name='CMsgClientMMSSetLobbyLinked',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyLinked.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyLinked.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby2', full_name='CMsgClientMMSSetLobbyLinked.steam_id_lobby2', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2870,
  serialized_end=2964,
)


_CMSGCLIENTMMSSETLOBBYGAMESERVER = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyGameServer',
  full_name='CMsgClientMMSSetLobbyGameServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyGameServer.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyGameServer.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_game_server_ip', full_name='CMsgClientMMSSetLobbyGameServer.deprecated_game_server_ip', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_server_port', full_name='CMsgClientMMSSetLobbyGameServer.game_server_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_server_steam_id', full_name='CMsgClientMMSSetLobbyGameServer.game_server_steam_id', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_server_ip', full_name='CMsgClientMMSSetLobbyGameServer.game_server_ip', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2967,
  serialized_end=3171,
)


_CMSGCLIENTMMSLOBBYGAMESERVERSET = _descriptor.Descriptor(
  name='CMsgClientMMSLobbyGameServerSet',
  full_name='CMsgClientMMSLobbyGameServerSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSLobbyGameServerSet.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSLobbyGameServerSet.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_game_server_ip', full_name='CMsgClientMMSLobbyGameServerSet.deprecated_game_server_ip', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_server_port', full_name='CMsgClientMMSLobbyGameServerSet.game_server_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_server_steam_id', full_name='CMsgClientMMSLobbyGameServerSet.game_server_steam_id', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_server_ip', full_name='CMsgClientMMSLobbyGameServerSet.game_server_ip', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3174,
  serialized_end=3378,
)


_CMSGCLIENTMMSUSERJOINEDLOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSUserJoinedLobby',
  full_name='CMsgClientMMSUserJoinedLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSUserJoinedLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSUserJoinedLobby.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_user', full_name='CMsgClientMMSUserJoinedLobby.steam_id_user', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgClientMMSUserJoinedLobby.persona_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3380,
  serialized_end=3495,
)


_CMSGCLIENTMMSUSERLEFTLOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSUserLeftLobby',
  full_name='CMsgClientMMSUserLeftLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSUserLeftLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSUserLeftLobby.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_user', full_name='CMsgClientMMSUserLeftLobby.steam_id_user', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgClientMMSUserLeftLobby.persona_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3497,
  serialized_end=3610,
)


_CMSGCLIENTMMSINVITETOLOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSInviteToLobby',
  full_name='CMsgClientMMSInviteToLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSInviteToLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSInviteToLobby.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_user_invited', full_name='CMsgClientMMSInviteToLobby.steam_id_user_invited', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3612,
  serialized_end=3711,
)


_CMSGCLIENTMMSGETLOBBYSTATUS = _descriptor.Descriptor(
  name='CMsgClientMMSGetLobbyStatus',
  full_name='CMsgClientMMSGetLobbyStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSGetLobbyStatus.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSGetLobbyStatus.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claim_membership', full_name='CMsgClientMMSGetLobbyStatus.claim_membership', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claim_ownership', full_name='CMsgClientMMSGetLobbyStatus.claim_ownership', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3713,
  serialized_end=3833,
)


_CMSGCLIENTMMSGETLOBBYSTATUSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSGetLobbyStatusResponse',
  full_name='CMsgClientMMSGetLobbyStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSGetLobbyStatusResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSGetLobbyStatusResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_status', full_name='CMsgClientMMSGetLobbyStatusResponse.lobby_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3836,
  serialized_end=3979,
)

_CMSGCLIENTMMSCREATELOBBY.fields_by_name['public_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER.containing_type = _CMSGCLIENTMMSJOINLOBBYRESPONSE
_CMSGCLIENTMMSJOINLOBBYRESPONSE.fields_by_name['members'].message_type = _CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER
_CMSGCLIENTMMSGETLOBBYLIST_FILTER.containing_type = _CMSGCLIENTMMSGETLOBBYLIST
_CMSGCLIENTMMSGETLOBBYLIST.fields_by_name['filters'].message_type = _CMSGCLIENTMMSGETLOBBYLIST_FILTER
_CMSGCLIENTMMSGETLOBBYLIST.fields_by_name['public_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY.containing_type = _CMSGCLIENTMMSGETLOBBYLISTRESPONSE
_CMSGCLIENTMMSGETLOBBYLISTRESPONSE.fields_by_name['lobbies'].message_type = _CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY
_CMSGCLIENTMMSLOBBYDATA_MEMBER.containing_type = _CMSGCLIENTMMSLOBBYDATA
_CMSGCLIENTMMSLOBBYDATA.fields_by_name['members'].message_type = _CMSGCLIENTMMSLOBBYDATA_MEMBER
_CMSGCLIENTMMSSETLOBBYGAMESERVER.fields_by_name['game_server_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGCLIENTMMSLOBBYGAMESERVERSET.fields_by_name['game_server_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGCLIENTMMSGETLOBBYSTATUSRESPONSE.fields_by_name['lobby_status'].enum_type = _EMMSLOBBYSTATUS
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetRatelimitPolicyOnClient'] = _CMSGCLIENTMMSSETRATELIMITPOLICYONCLIENT
DESCRIPTOR.message_types_by_name['CMsgClientMMSCreateLobby'] = _CMSGCLIENTMMSCREATELOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSCreateLobbyResponse'] = _CMSGCLIENTMMSCREATELOBBYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSJoinLobby'] = _CMSGCLIENTMMSJOINLOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSJoinLobbyResponse'] = _CMSGCLIENTMMSJOINLOBBYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSLeaveLobby'] = _CMSGCLIENTMMSLEAVELOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSLeaveLobbyResponse'] = _CMSGCLIENTMMSLEAVELOBBYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSGetLobbyList'] = _CMSGCLIENTMMSGETLOBBYLIST
DESCRIPTOR.message_types_by_name['CMsgClientMMSGetLobbyListResponse'] = _CMSGCLIENTMMSGETLOBBYLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyData'] = _CMSGCLIENTMMSSETLOBBYDATA
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyDataResponse'] = _CMSGCLIENTMMSSETLOBBYDATARESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSGetLobbyData'] = _CMSGCLIENTMMSGETLOBBYDATA
DESCRIPTOR.message_types_by_name['CMsgClientMMSLobbyData'] = _CMSGCLIENTMMSLOBBYDATA
DESCRIPTOR.message_types_by_name['CMsgClientMMSSendLobbyChatMsg'] = _CMSGCLIENTMMSSENDLOBBYCHATMSG
DESCRIPTOR.message_types_by_name['CMsgClientMMSLobbyChatMsg'] = _CMSGCLIENTMMSLOBBYCHATMSG
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyOwner'] = _CMSGCLIENTMMSSETLOBBYOWNER
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyOwnerResponse'] = _CMSGCLIENTMMSSETLOBBYOWNERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyLinked'] = _CMSGCLIENTMMSSETLOBBYLINKED
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyGameServer'] = _CMSGCLIENTMMSSETLOBBYGAMESERVER
DESCRIPTOR.message_types_by_name['CMsgClientMMSLobbyGameServerSet'] = _CMSGCLIENTMMSLOBBYGAMESERVERSET
DESCRIPTOR.message_types_by_name['CMsgClientMMSUserJoinedLobby'] = _CMSGCLIENTMMSUSERJOINEDLOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSUserLeftLobby'] = _CMSGCLIENTMMSUSERLEFTLOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSInviteToLobby'] = _CMSGCLIENTMMSINVITETOLOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSGetLobbyStatus'] = _CMSGCLIENTMMSGETLOBBYSTATUS
DESCRIPTOR.message_types_by_name['CMsgClientMMSGetLobbyStatusResponse'] = _CMSGCLIENTMMSGETLOBBYSTATUSRESPONSE
DESCRIPTOR.enum_types_by_name['EMMSLobbyStatus'] = _EMMSLOBBYSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgClientMMSSetRatelimitPolicyOnClient = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetRatelimitPolicyOnClient', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSSETRATELIMITPOLICYONCLIENT,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetRatelimitPolicyOnClient)
  })
_sym_db.RegisterMessage(CMsgClientMMSSetRatelimitPolicyOnClient)

CMsgClientMMSCreateLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSCreateLobby', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSCREATELOBBY,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSCreateLobby)
  })
_sym_db.RegisterMessage(CMsgClientMMSCreateLobby)

CMsgClientMMSCreateLobbyResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSCreateLobbyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSCREATELOBBYRESPONSE,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSCreateLobbyResponse)
  })
_sym_db.RegisterMessage(CMsgClientMMSCreateLobbyResponse)

CMsgClientMMSJoinLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSJoinLobby', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSJOINLOBBY,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSJoinLobby)
  })
_sym_db.RegisterMessage(CMsgClientMMSJoinLobby)

CMsgClientMMSJoinLobbyResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSJoinLobbyResponse', (_message.Message,), {

  'Member' : _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER,
    '__module__' : 'steammessages_clientserver_mms_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientMMSJoinLobbyResponse.Member)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTMMSJOINLOBBYRESPONSE,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSJoinLobbyResponse)
  })
_sym_db.RegisterMessage(CMsgClientMMSJoinLobbyResponse)
_sym_db.RegisterMessage(CMsgClientMMSJoinLobbyResponse.Member)

CMsgClientMMSLeaveLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSLeaveLobby', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSLEAVELOBBY,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSLeaveLobby)
  })
_sym_db.RegisterMessage(CMsgClientMMSLeaveLobby)

CMsgClientMMSLeaveLobbyResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSLeaveLobbyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSLEAVELOBBYRESPONSE,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSLeaveLobbyResponse)
  })
_sym_db.RegisterMessage(CMsgClientMMSLeaveLobbyResponse)

CMsgClientMMSGetLobbyList = _reflection.GeneratedProtocolMessageType('CMsgClientMMSGetLobbyList', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTMMSGETLOBBYLIST_FILTER,
    '__module__' : 'steammessages_clientserver_mms_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyList.Filter)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTMMSGETLOBBYLIST,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyList)
  })
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyList)
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyList.Filter)

CMsgClientMMSGetLobbyListResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSGetLobbyListResponse', (_message.Message,), {

  'Lobby' : _reflection.GeneratedProtocolMessageType('Lobby', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY,
    '__module__' : 'steammessages_clientserver_mms_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyListResponse.Lobby)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTMMSGETLOBBYLISTRESPONSE,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyListResponse)
  })
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyListResponse)
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyListResponse.Lobby)

CMsgClientMMSSetLobbyData = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyData', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSSETLOBBYDATA,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyData)
  })
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyData)

CMsgClientMMSSetLobbyDataResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSSETLOBBYDATARESPONSE,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyDataResponse)
  })
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyDataResponse)

CMsgClientMMSGetLobbyData = _reflection.GeneratedProtocolMessageType('CMsgClientMMSGetLobbyData', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSGETLOBBYDATA,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyData)
  })
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyData)

CMsgClientMMSLobbyData = _reflection.GeneratedProtocolMessageType('CMsgClientMMSLobbyData', (_message.Message,), {

  'Member' : _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTMMSLOBBYDATA_MEMBER,
    '__module__' : 'steammessages_clientserver_mms_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientMMSLobbyData.Member)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTMMSLOBBYDATA,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSLobbyData)
  })
_sym_db.RegisterMessage(CMsgClientMMSLobbyData)
_sym_db.RegisterMessage(CMsgClientMMSLobbyData.Member)

CMsgClientMMSSendLobbyChatMsg = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSendLobbyChatMsg', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSSENDLOBBYCHATMSG,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSendLobbyChatMsg)
  })
_sym_db.RegisterMessage(CMsgClientMMSSendLobbyChatMsg)

CMsgClientMMSLobbyChatMsg = _reflection.GeneratedProtocolMessageType('CMsgClientMMSLobbyChatMsg', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSLOBBYCHATMSG,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSLobbyChatMsg)
  })
_sym_db.RegisterMessage(CMsgClientMMSLobbyChatMsg)

CMsgClientMMSSetLobbyOwner = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyOwner', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSSETLOBBYOWNER,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyOwner)
  })
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyOwner)

CMsgClientMMSSetLobbyOwnerResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyOwnerResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSSETLOBBYOWNERRESPONSE,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyOwnerResponse)
  })
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyOwnerResponse)

CMsgClientMMSSetLobbyLinked = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyLinked', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSSETLOBBYLINKED,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyLinked)
  })
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyLinked)

CMsgClientMMSSetLobbyGameServer = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyGameServer', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSSETLOBBYGAMESERVER,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyGameServer)
  })
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyGameServer)

CMsgClientMMSLobbyGameServerSet = _reflection.GeneratedProtocolMessageType('CMsgClientMMSLobbyGameServerSet', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSLOBBYGAMESERVERSET,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSLobbyGameServerSet)
  })
_sym_db.RegisterMessage(CMsgClientMMSLobbyGameServerSet)

CMsgClientMMSUserJoinedLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSUserJoinedLobby', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSUSERJOINEDLOBBY,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSUserJoinedLobby)
  })
_sym_db.RegisterMessage(CMsgClientMMSUserJoinedLobby)

CMsgClientMMSUserLeftLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSUserLeftLobby', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSUSERLEFTLOBBY,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSUserLeftLobby)
  })
_sym_db.RegisterMessage(CMsgClientMMSUserLeftLobby)

CMsgClientMMSInviteToLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSInviteToLobby', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSINVITETOLOBBY,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSInviteToLobby)
  })
_sym_db.RegisterMessage(CMsgClientMMSInviteToLobby)

CMsgClientMMSGetLobbyStatus = _reflection.GeneratedProtocolMessageType('CMsgClientMMSGetLobbyStatus', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSGETLOBBYSTATUS,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyStatus)
  })
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyStatus)

CMsgClientMMSGetLobbyStatusResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSGetLobbyStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMMSGETLOBBYSTATUSRESPONSE,
  '__module__' : 'steammessages_clientserver_mms_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyStatusResponse)
  })
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyStatusResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_unified_base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_unified_base.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n steammessages_unified_base.proto\x1a google/protobuf/descriptor.proto\"\x0c\n\nNoResponse*]\n\x13\x45ProtoExecutionSite\x12 \n\x1ck_EProtoExecutionSiteUnknown\x10\x00\x12$\n k_EProtoExecutionSiteSteamClient\x10\x02:4\n\x0b\x64\x65scription\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\t:>\n\x13service_description\x12\x1f.google.protobuf.ServiceOptions\x18\xd0\x86\x03 \x01(\t:u\n\x16service_execution_site\x12\x1f.google.protobuf.ServiceOptions\x18\xd8\x86\x03 \x01(\x0e\x32\x14.EProtoExecutionSite:\x1ck_EProtoExecutionSiteUnknown:<\n\x12method_description\x12\x1e.google.protobuf.MethodOptions\x18\xd0\x86\x03 \x01(\t:8\n\x10\x65num_description\x12\x1c.google.protobuf.EnumOptions\x18\xd0\x86\x03 \x01(\t:C\n\x16\x65num_value_description\x12!.google.protobuf.EnumValueOptions\x18\xd0\x86\x03 \x01(\tB\x05H\x01\x90\x01\x00'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])

_EPROTOEXECUTIONSITE = _descriptor.EnumDescriptor(
  name='EProtoExecutionSite',
  full_name='EProtoExecutionSite',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EProtoExecutionSiteUnknown', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EProtoExecutionSiteSteamClient', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=84,
  serialized_end=177,
)
_sym_db.RegisterEnumDescriptor(_EPROTOEXECUTIONSITE)

EProtoExecutionSite = enum_type_wrapper.EnumTypeWrapper(_EPROTOEXECUTIONSITE)
k_EProtoExecutionSiteUnknown = 0
k_EProtoExecutionSiteSteamClient = 2

DESCRIPTION_FIELD_NUMBER = 50000
description = _descriptor.FieldDescriptor(
  name='description', full_name='description', index=0,
  number=50000, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
SERVICE_DESCRIPTION_FIELD_NUMBER = 50000
service_description = _descriptor.FieldDescriptor(
  name='service_description', full_name='service_description', index=1,
  number=50000, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
SERVICE_EXECUTION_SITE_FIELD_NUMBER = 50008
service_execution_site = _descriptor.FieldDescriptor(
  name='service_execution_site', full_name='service_execution_site', index=2,
  number=50008, type=14, cpp_type=8, label=1,
  has_default_value=True, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
METHOD_DESCRIPTION_FIELD_NUMBER = 50000
method_description = _descriptor.FieldDescriptor(
  name='method_description', full_name='method_description', index=3,
  number=50000, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUM_DESCRIPTION_FIELD_NUMBER = 50000
enum_description = _descriptor.FieldDescriptor(
  name='enum_description', full_name='enum_description', index=4,
  number=50000, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUM_VALUE_DESCRIPTION_FIELD_NUMBER = 50000
enum_value_description = _descriptor.FieldDescriptor(
  name='enum_value_description', full_name='enum_value_description', index=5,
  number=50000, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_NORESPONSE = _descriptor.Descriptor(
  name='NoResponse',
  full_name='NoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=82,
)

DESCRIPTOR.message_types_by_name['NoResponse'] = _NORESPONSE
DESCRIPTOR.enum_types_by_name['EProtoExecutionSite'] = _EPROTOEXECUTIONSITE
DESCRIPTOR.extensions_by_name['description'] = description
DESCRIPTOR.extensions_by_name['service_description'] = service_description
DESCRIPTOR.extensions_by_name['service_execution_site'] = service_execution_site
DESCRIPTOR.extensions_by_name['method_description'] = method_description
DESCRIPTOR.extensions_by_name['enum_description'] = enum_description
DESCRIPTOR.extensions_by_name['enum_value_description'] = enum_value_description
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NoResponse = _reflection.GeneratedProtocolMessageType('NoResponse', (_message.Message,), {
  'DESCRIPTOR' : _NORESPONSE,
  '__module__' : 'steammessages_unified_base_pb2'
  # @@protoc_insertion_point(class_scope:NoResponse)
  })
_sym_db.RegisterMessage(NoResponse)

google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(description)
google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_description)
service_execution_site.enum_type = _EPROTOEXECUTIONSITE
google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_execution_site)
google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_description)
google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enum_description)
google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(enum_value_description)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
